/*                
 *                        Licensing Notification
 *
 * Permission to use, reproduce, prepare derivative works, and to redistribute
 * to others this software and its documentation is hereby granted, provided
 * that this notice is retained thereon and on all copies or modifications. UChicago
 * Argonne, LLC, Tech-X Corporation, and all other contributors make no representations
 * as to the suitability and operability of this software for any purpose. It is
 * provided "as is" without express or implied warranty.
 *
 */

#ifndef CSR_MATRIX_DATA_H
#define CSR_MATRIX_DATA_H

// -----------------------------------------------------------------------------

template<typename index_type, typename value_type>
struct csr_matrix_data
{
	csr_matrix_data()
		: num_rows(index_type()),
		  num_cols(index_type()),
		  num_entries(index_type()),
		  row_offsets(0),
		  column_indices(0),
		  values(0)
	{
	}

	csr_matrix_data(index_type  in_num_rows,
	                index_type  in_num_cols,
					index_type  in_num_entries,
					index_type* in_row_offsets,
					index_type* in_column_indices,
					value_type* in_values)
		: num_rows(in_num_rows),
		  num_cols(in_num_cols),
		  num_entries(in_num_entries),
		  row_offsets(in_row_offsets),
		  column_indices(in_column_indices),
		  values(in_values)
	{
	}

	virtual ~csr_matrix_data()
	{
		clear();
	}

	virtual bool clear()
	{
		num_rows       = index_type();
		num_cols       = index_type();
		num_entries    = index_type();
		row_offsets    = 0;
		column_indices = 0;
		values         = 0;

		return true;
	}

	index_type  num_rows;
	index_type  num_cols;
	index_type  num_entries;
	index_type* row_offsets;
	index_type* column_indices;
	value_type* values;

private:

	csr_matrix_data(const csr_matrix_data&);
	csr_matrix_data& operator=(const csr_matrix_data&);
};

// -----------------------------------------------------------------------------

#endif // CSR_MATRIX_DATA_H
